@@ -1,5 +1,5 @@
 package Bot::Cobalt::Frontend::Utils;
-$Bot::Cobalt::Frontend::Utils::VERSION = '0.019002';
+$Bot::Cobalt::Frontend::Utils::VERSION = '0.019003';
 use v5.10;
 use strictures 2;
 
@@ -38,9 +38,9 @@ sub ask_question {
   };
 
   my $input = $print_and_grab->();
-  until ($input) {
+  until (length $input) {
     print "No input specified.\n";
-    $print_and_grab->();
+    $input = $print_and_grab->()
   }
 
   VALID: {
